# CoRT-SI: Selective Inference For Co-Regularization Transfer (CoRT)

**CoRT-SI** is a Python package designed for conducting valid statistical inference for CoRT. It implements selective inference methods to control the false positive rate (FPR) while maximizing the true positive rate (TPR) in feature selection after transfer learning.

## Requirements & Installation

This package has the following requirements:

* `numpy`
* `mpmath`
* `scikit-learn`

This package can be installed using pip:

```bash
pip install cort-si